@@ -73,7 +73,7 @@
 //#include "kdebug.h"
 
 extern "C" {
-KDE_EXPORT	KPanelApplet* init( TQWidget* inParent, const TQString& inConfigFile) {
+TDE_EXPORT	KPanelApplet* init( TQWidget* inParent, const TQString& inConfigFile) {
 		TDEGlobal::locale()->insertCatalogue("kima");
 		return new Kima(inConfigFile, KPanelApplet::Normal,
 		                      //KPanelApplet::About | KPanelApplet::Help | KPanelApplet::Preferences,
